Base64Value class

A container for a base64 encoded value.

Constructors

Base64Value(List<int>? _bytes)
Base64Value.fromBase64String(String? _base64String)

Properties

base64String → String
no setter
bytes → List<int>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited